# Mesh

Mesh commands are used to mesh part instances and regions. Mesh commands are also used to assign element sizes, element types, and mesh control parameters.

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Mesh
        :recursive:

    .. placeholder for empty members
```
